diff -r 97b4f578ce38 -r 2b4b3ab2b351 channels/chan_sip.c
--- a/channels/chan_sip.c	Tue Dec 10 13:22:25 2013 +0000
+++ b/channels/chan_sip.c	Thu Dec 12 12:49:59 2013 +0000
@@ -20860,6 +20860,8 @@
 #define FORMAT3 "%-15.15s  %-15.15s  %-15.15s  %-15.15s  %-13.13s  %-15.15s %-10.10s %-6.6s\n"
 #define FORMAT2 "%-15.15s  %-15.15s  %-15.15s  %-15.15s  %-7.7s  %-15.15s %-10.10s %-10.10s\n"
 #define FORMAT  "%-15.15s  %-15.15s  %-15.15s  %-15.15s  %-3.3s %-3.3s  %-15.15s %-10.10s %-10.10s\n"
+#define SHOW_CHANNELS_RETRIES 10
+#define SHOW_CHANNELS_WAIT 100
 
 /*! \brief callback for show channel|subscription */
 static int show_channels_cb(void *__cur, void *__arg, int flags)
@@ -20867,8 +20869,27 @@
 	struct sip_pvt *cur = __cur;
 	struct __show_chan_arg *arg = __arg;
 	const struct ast_sockaddr *dst;
-
-	sip_pvt_lock(cur);
+	int tries = 0;
+
+	/*
+	 * There is a conflict between the 'sip show channels' function and attended transfers.
+	 * - 'sip show channels' locks the dialogs list, and then tries to lock each sip_pvt within it.
+	 * - attended transfers happen with a sip_pvt locked, and while doing a lookup, attempt
+	 *   to lock the dialogs list.
+	 * There is therefore a possibility of deadlock, so we avoid it here.
+	 */
+	for (tries = 0; tries < SHOW_CHANNELS_RETRIES; tries++) {
+		if (sip_pvt_trylock(cur) == 0)
+			break;
+		usleep(SHOW_CHANNELS_WAIT);
+	}
+
+	/* if tries reached the maximum number then the lock was NOT obtained */
+	if (tries == SHOW_CHANNELS_RETRIES) {
+		ast_cli(arg->fd, "(Channel locked - deadlock avoided)\n");
+		return 0;
+	}
+
 	dst = sip_real_dst(cur);
 
 	/* XXX indentation preserved to reduce diff. Will be fixed later */
